@@ -3,7 +3,7 @@ import glob
 import os
 import random
 
-__version__ = "1.3.1"
+__version__ = "1.4.0"
 
 class TailedFile:
    def __init__(self, path, skip_to_end = True, offset = None):
@@ -39,7 +39,14 @@ class TailedFile:
 
    def _read(self, limit = None):
       """Checks the file for new data and refills the buffer if it finds any."""
-      self._buf += self._fh.read(limit)
+      # 64k ought to be enough for anybody
+      limit = limit or 65535
+      while True:
+         data = os.read(self._fh.fileno(), limit)
+         if data == '':
+            break
+         self._buf += data
+
 
    def hasBeenRotated(self):
       """Returns a boolean indicating whether the file has been removed and recreated during the time it has been open."""
@@ -171,4 +178,3 @@ class MultiTail:
       for path, tailedfile in self._tailedfiles.iteritems():
          yield path, tailedfile._offset
 
-
